#!/usr/bin/env python3

# Contributed by Raju and updated by Jim
# February 2018 updated, now requires I2C address for each command, this
# matches micropython and so can be used the same way
# Also general call added
# 
# Use:
# import i2cc_p as iic 
# dev = iic.IIC(<Bus number>)
#
import io
import fcntl

I2C_SLAVE=0x0703

# Based on 'notSMB' for an easier way to access the i2c bus using just one
# function. 
class IIC:
   def __init__(self, bus):

      self.fr = io.open("/dev/i2c-"+str(bus), "rb", buffering=0)
      self.fw = io.open("/dev/i2c-"+str(bus), "wb", buffering=0)

   def write(self,adr, data):
      fcntl.ioctl(self.fw, I2C_SLAVE, adr)  
      if type(data) is list:
         data = bytes(data)
      self.fw.write(data)

   # python 3 return as list of integer
   def read(self,adr, count):
      fcntl.ioctl(self.fr, I2C_SLAVE, adr)
      l = []
      s = self.fr.read(count)
      if len(s) != 0:
         for n in s:
            l.append(n)
      return l
    

   def close(self):
      self.fw.close()
      self.fr.close()
      
   # If general call is set then that address is used for writing instead
   # of the device address, but the device address is used for reading (if any)
   # e.g dev.i2c(35,[1,2],1) # no general call
   #     dev.i2c(35,[1,2,3],1,0) # using general call
   def i2c(self,adr,inputv,outputn,gc=None):
       if isinstance(inputv,list):
           b = bytes(inputv)
           if gc is not None:
               self.write(gc,b)
           else:    
               self.write(adr,b)
           # do output
           if outputn > 0:
               return self.read(adr,outputn)
       else:
           print('iic input must be a list')       
      
