# P018 I2C chip
#          default addtess is 56
# use:
#   ---- i2c RPi ---
#   import i2c_p
#   i2c = i2c_p.IIC(1) 
#   ---- i2c ESP8266 ---
#   import i2c_u
#   i2c = i2c_u.IIC(-- see options--)  
#   ------------
#   import p018
#   dev = p018.P018(i2c=i2c)
#   dev.
#
#
class P018():
    def __init__(self,address=56,i2c=None):
        self.bus = i2c
        self.adr = address
        self.ROW = [0x80,0xc0,0x94,0xd4] # usual LCD rows but not always, change as required

    # ============ S Y S T E M =================================================
    #---------------------------------------------------------------------------
    # read eeprom single byte at address
    #---------------------------------------------------------------------------
    def eeread(self,addr):
        return self.bus.i2c(self.adr,[0x90,addr],1)[0]

    #---------------------------------------------------------------------------
    # write eeprom single byte at address
    #---------------------------------------------------------------------------
    def eewrite(self,addr,value):
        self.bus.i2c(self.adr,[0x91,addr,value],0) 

    #---------------------------------------------------------------------------
    # change i2caddress
    #---------------------------------------------------------------------------
    def newaddress(self,addr):
        self.eewrite(1,addr)
        self.eewrite(14,addr)
        self.eewrite(250,addr)

    #---------------------------------------------------------------------------
    # gets device id 2 bytes
    #---------------------------------------------------------------------------
    def deviceid(self):
        l = self.bus.i2c(self.adr,[0xa1],2)
        return (l[0] * 256) + l[1]

    #---------------------------------------------------------------------------
    # gets firemware version 3 bytes
    #---------------------------------------------------------------------------
    def firmware(self):
        l = self.bus.i2c(self.adr,[0xa0],2)
        return ('{}.{}'.format(l[0],l[1]))

    #---------------------------------------------------------------------------
    # reset
    #---------------------------------------------------------------------------
    def reset(self):
        self.bus.i2c(self.adr,[0x95],0)

    # **************************************************************************
    # L C D
    #---------------------------------------------------------------------------
    # Back light r,g,b - max 10
    #---------------------------------------------------------------------------
    def bl(self,r,g,b):
        # check range 1-10
        if r > 9: r = 9
        if r < 0: r = 0
        if g > 9: g = 9
        if g < 0: g = 0
        if b > 9: b = 9
        if b < 0: b = 0
        self.bus.i2c(self.adr,[1,r,g,b],0)    

    #---------------------------------------------------------------------------
    # command - sends command directly to lcd controller
    #---------------------------------------------------------------------------
    def cmd(self,v):
        self.bus.i2c(self.adr,[2,v],0)    

    #---------------------------------------------------------------------------
    # Send string
    #---------------------------------------------------------------------------
    def puts(self,s):
        l = [3]
        cr = False
        for n in s:
            l.append(ord(n))
            if ord(n) == 13:
                cr = True
        if cr == False:
            l.append(13)            
        self.bus.i2c(self.adr,l,0)    

    # ==========================================================================
    # Compound commands
    #---------------------------------------------------------------------------
    # 
    #---------------------------------------------------------------------------
    def cls(self):
        self.cmd(1)
    #---------------------------------------------------------------------------
    # cursor
    def csroff(self):
        self.cmd(12)
    def csrflash(self):   
        self.cmd(15)
    def csron(self):
        self.cmd(14)
    #---------------------------------------------------------------------------
    # row col starts at 0
    def rc(self,row,col):
        if row > 3 : row = 3
        if row < 0 : row = 0
        d = self.ROW[row] + col
        self.cmd(d)                

